@@ -5,19 +5,18 @@
  *                            | (__| |_| |  _ <| |___
  *                             \___|\___/|_| \_\_____|
  *
- * $Id: first.c,v 1.17 2007-10-02 16:05:28 yangtse Exp $
  */
 
 #include "test.h"
 
-#ifdef CURLDEBUG
-/* provide a proto for this debug function */
-extern void curl_memdebug(const char *);
-extern void curl_memlimit(int);
+#ifdef HAVE_LOCALE_H
+#include <locale.h> /* for setlocale() */
 #endif
 
-/* test is provided in the test code file */
-int test(char *url);
+#ifdef CURLDEBUG
+#  define MEMDEBUG_NODEFINES
+#  include "memdebug.h"
+#endif
 
 int select_test (int num_fds, fd_set *rd, fd_set *wr, fd_set *exc,
                  struct timeval *tv)
@@ -38,7 +37,7 @@ char *libtest_arg2=NULL;
 char *libtest_arg3=NULL;
 int test_argc;
 char **test_argv;
-
+int unitfail; /* for unittests */
 
 int main(int argc, char **argv)
 {
@@ -60,10 +59,23 @@ int main(int argc, char **argv)
   /* this enables the fail-on-alloc-number-N functionality */
   env = curl_getenv("CURL_MEMLIMIT");
   if(env) {
-    curl_memlimit(atoi(env));
+    char *endptr;
+    long num = strtol(env, &endptr, 10);
+    if((endptr != env) && (endptr == env + strlen(env)) && (num > 0))
+      curl_memlimit(num);
     curl_free(env);
   }
 #endif
+
+  /*
+   * Setup proper locale from environment. This is needed to enable locale-
+   * specific behaviour by the C library in order to test for undesired side
+   * effects that could cause in libcurl.
+   */
+#ifdef HAVE_SETLOCALE
+  setlocale(LC_ALL, "");
+#endif
+
   if(argc< 2 ) {
     fprintf(stderr, "Pass URL as argument please\n");
     return 1;
